==> Postcode-1.1.1.tar.gz: Postcode/lang/en_US.php <==
<?php
#A

#B

#C
$lang['changelog'] = 'Changelog';
$lang['country'] = 'Country';

#D

#E
$lang['error_duplicatepostal'] = 'A duplicate postal code entry was found at line %d';
$lang['error_empty_delimiter'] = 'You must specify a delimiter';
$lang['error_empty_fieldmap'] = 'You must specify a field map';
$lang['error_fileupload'] = 'Problem uploading import file';
$lang['error_invalidmap'] = 'The field map you specified is invalid or has an error';
$lang['error_insertfailed'] = 'Error at line %d, database insert failed';
$lang['error_lookup_failed'] = 'Postal code lookup failed';
$lang['error_nofile'] = 'No import file was specified';
$lang['error_numfields'] = 'Error at line %d, insufficient number of fields';
$lang['error_readfile'] = 'A problem occurred trying to read the uploaded file';

#F
$lang['friendlyname'] = 'PostCode Lookup';

#G

#H
$lang['help'] = <<<EOT
TODO
EOT;

#I
$lang['import'] = 'Import';
$lang['import_policy_error'] = 'Report Error';
$lang['import_policy_ignore'] = 'Silently Ignore';
$lang['import_policy_overwrite'] = 'Replace Original Values';
$lang['info_delimeter'] = 'Specify the character(s) that seperate each column of the file.  Use the string [TAB] to indicate the tab character.';
$lang['info_effective_chars'] = 'Some regions <em>(Canada)</em> may have long postcodes to identify specific regions, but the database only contains keys for prefixes of a certain length.  This field will effectively trim the supplied postcode to the number of effective characters before submitting the database request.';
$lang['info_fieldmap'] = <<<EOT
This field defines the map between required fields and import file columns.  The format should be of the form &quot;name=number&quot; where the name is one of the possible names below, and the number is a column number (starting from 1).<br/><br/>
<h5>Field Names:</h5>
<ul>
  <li>country - the country code</li>
  <li>postal - the postal code</li>
  <li>placename - A logical place name</li>
  <li>latitude - the latitude in decimal format</li>
  <li>longitude - the longitude in decimal format</li>
</ul>
EOT;

#J

#K

#L
$lang['latitude'] = 'Latitude';
$lang['longitude'] = 'Longitude';
$lang['lookup'] = 'Lookup';
$lang['lookup_successful'] = 'Successful Lookup';

#M
$lang['moddescription'] = 'A simple module to allow converting postal or zip codes to latitude and longitude based on the geonames service';
$lang['msg_import_numimported'] = 'Imported %d records';

#N

#O
$lang['opmode_dbfirst'] = 'Database First, then Online';
$lang['opmode_dbfirst_cache'] = 'Database First, then Online with Caching';
$lang['opmode_dbonly'] = 'Database Only';
$lang['opmode_onlineonly'] = 'Online lookups only';

#P
$lang['place_name'] = 'Place Name';
$lang['postal_code'] = 'Postal Code / Zip Code';
$lang['postinstall'] = 'The Postcode module has been installed';
$lang['postuninstall'] = 'The Postcode module has been uninstall';
$lang['preferences'] = 'Preferences';
$lang['prev'] = 'Back';
$lang['prompt_assume_country'] = 'If not specified, assume this country';
$lang['prompt_delimiter'] = 'Delimiter';
$lang['prompt_duplicate_policy'] = 'Duplicated postal code policy';
$lang['prompt_effective_chars'] = 'Number of effective characters in postcode search';
$lang['prompt_fieldmap'] = 'Field Map';
$lang['prompt_file'] = 'File';
$lang['prompt_operation_mode'] = 'Operation Mode';

#Q

#R
$lang['really_uninstall'] = 'Are you sure you want to do this?';

#S
$lang['submit'] = 'Submit';

#T

#U

#V

#W

#X

#Y

#Z
?>

==> Postcode-1.2.1.tar.gz: Postcode/lang/en_US.php <==
<?php
#A

#B

#C
$lang['changelog'] = 'Changelog';
$lang['country'] = 'Country';

#D

#E
$lang['error_duplicatepostal'] = 'A duplicate postal code entry was found at line %d';
$lang['error_empty_delimiter'] = 'You must specify a delimiter';
$lang['error_empty_fieldmap'] = 'You must specify a field map';
$lang['error_fileupload'] = 'Problem uploading import file';
$lang['error_invalidmap'] = 'The field map you specified is invalid or has an error';
$lang['error_insertfailed'] = 'Error at line %d, database insert failed';
$lang['error_lookup_failed'] = 'Postal code lookup failed';
$lang['error_nofile'] = 'No import file was specified';
$lang['error_numfields'] = 'Error at line %d, insufficient number of fields';
$lang['error_readfile'] = 'A problem occurred trying to read the uploaded file';

#F
$lang['friendlyname'] = 'PostCode Lookup';

#G

#H

#I
$lang['import'] = 'Import';
$lang['import_policy_error'] = 'Report Error';
$lang['import_policy_ignore'] = 'Silently Ignore';
$lang['import_policy_overwrite'] = 'Replace Original Values';
$lang['info_delimeter'] = 'Specify the character(s) that seperate each column of the file.  Use the string [TAB] to indicate the tab character.';
$lang['info_effective_chars'] = 'Some regions <em>(Canada)</em> may have long postcodes to identify specific regions, but the database only contains keys for prefixes of a certain length.  This field will effectively trim the supplied postcode to the number of effective characters before submitting the database request.';
$lang['info_fieldmap'] = <<<EOT
This field defines the map between required fields and import file columns.  The format should be of the form &quot;name=number&quot; where the name is one of the possible names below, and the number is a column number (starting from 1).<br/><br/>
<h5>Field Names:</h5>
<ul>
  <li>country - the country code</li>
  <li>postal - the postal code</li>
  <li>placename - A logical place name</li>
  <li>latitude - the latitude in decimal format</li>
  <li>longitude - the longitude in decimal format</li>
</ul>
EOT;

#J

#K

#L
$lang['latitude'] = 'Latitude';
$lang['longitude'] = 'Longitude';
$lang['lookup'] = 'Lookup';
$lang['lookup_successful'] = 'Successful Lookup';

#M
$lang['moddescription'] = 'A simple module to allow converting postal or zip codes to latitude and longitude based on the geonames service';
$lang['msg_import_numimported'] = 'Imported %d records';
$lang['msg_prefs_saved'] = 'Preferences Saved';

#N

#O
$lang['opmode_dbfirst'] = 'Database First, then Online';
$lang['opmode_dbfirst_cache'] = 'Database First, then Online with Caching';
$lang['opmode_dbonly'] = 'Database Only';
$lang['opmode_onlineonly'] = 'Online lookups only';

#P
$lang['place_name'] = 'Place Name';
$lang['postal_code'] = 'Postal Code / Zip Code';
$lang['postinstall'] = 'The Postcode module has been installed';
$lang['postuninstall'] = 'The Postcode module has been uninstall';
$lang['preferences'] = 'Preferences';
$lang['prev'] = 'Back';
$lang['prompt_assume_country'] = 'If not specified, assume this country';
$lang['prompt_delimiter'] = 'Delimiter';
$lang['prompt_duplicate_policy'] = 'Duplicated postal code policy';
$lang['prompt_effective_chars'] = 'Number of effective characters in postcode search';
$lang['prompt_fieldmap'] = 'Field Map';
$lang['prompt_file'] = 'File';
$lang['prompt_operation_mode'] = 'Operation Mode';
$lang['prompt_username'] = 'Geonames Username';

#Q

#R
$lang['really_uninstall'] = 'Are you sure you want to do this?';

#S
$lang['submit'] = 'Submit';

#T

#U

#V

#W

#X

#Y

#Z
?>
